.. moduleauthor:: Paul Ross <apaulross@gmail.com>
.. sectionauthor:: Paul Ross <apaulross@gmail.com>

TotalDepth.util.plot.Stroke (Plot Pen Stroke)
==================================================

.. automodule:: TotalDepth.util.plot.Stroke
    :member-order: bysource
    :members:
    :special-members:
